@@ -32,7 +32,7 @@ class TestSage : public BackendTest
 {
   Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     //tests evaluating a simple command
     void testSimpleCommand();
 
@@ -56,7 +56,7 @@ private slots:
     void testNoOutput();
 
 private:
-    virtual QString backendName();
+    QString backendName() Q_DECL_OVERRIDE;
 
 };
 
